Module theme

Module theme 

Structs

CssClassPartials
Partial CSS class name for each theme attribute. Map<ThemeAttr, String> newtype.
StyleAliases
A map of style aliases to their style property definitions.
ThemeDefault
Default theme styles when the diagram has no user interaction.
ThemeStyles
CSS utility class partials for each element. Map<IdOrDefaults, CssClassPartials> newtype.
ThemeTagThingsFocus
Styles when a tag is focused, applied to all tags or specific tags.
ThemeThingDependenciesStyles
Styles when a thing is focused to show its dependencies.
ThemeTypesStyles
Styles applied to things / edges of a particular type specified in entity_types.
ThingsFocusStyles
Styles for things that are included or excluded from focus.

Enums

IdOrDefaults
Key to specify tailwind styles for all kinds of nodes and edges.
StyleAlias
Style alias for grouping style properties under a single name.
TagIdOrDefaults
Key to specify styles for tag focus, either defaults or a specific tag.
ThemeAttr
Themeable attributes of nodes and edges.